@@ -44,7 +44,12 @@ def get_services_id(
         if not output:
             msg = "No output from docker compose"
             raise ZValueError(
-                msg, wd=wd, project=project, cmd=" ".join(cmd), output=output.decode(), services=services,
+                msg,
+                wd=wd,
+                project=project,
+                cmd=" ".join(cmd),
+                output=output.decode(),
+                services=services,
             )
 
         container_ids = output.decode("utf-8").strip().split("\n")  # \n at the end
@@ -69,7 +74,7 @@ def get_services_id(
 
 
 def run_docker(cwd: str, project: str, cmd0: List[str], get_output: bool = False) -> bytes:
-    """ raises DockerComposeFail """
+    """raises DockerComposeFail"""
     cmd0 = ["docker-compose", "-p", project] + cmd0
     # logger.info('Running:\n\t%s' % " ".join(cmd0) + '\n\n in %s' % cwd)
     logger.debug(cwd=cwd, command=" ".join(cmd0))
