@@ -15,9 +15,9 @@ class DockerLoginError(ZException):
 
 
 def do_docker_login(docker_username: str, docker_password: str, force=False):
-    AIDO_REGISTRY = os.environ.get(ENV_REGISTRY, "docker.io")
-    if not force and ("duckietown.org" in AIDO_REGISTRY):
-        logger.info(f"No need to login for registry {AIDO_REGISTRY}")
+    USE_REGISTRY = os.environ.get(ENV_REGISTRY, "docker.io")
+    if not force and ("duckietown.org" in USE_REGISTRY):
+        logger.info(f"No need to login for registry {USE_REGISTRY}")
         return
     cmd = ["docker", "login", "-u", docker_username, "--password-stdin"]
     try:
