@@ -133,15 +133,18 @@ Usage:
         res = ev in os.environ
         if not res:
             logger.debug(f"not found {ev}")
+        else:
+            logger.info(f"Using {v=} = {ev} = {res!r}")
         return res
 
     def get_env_value_or_none(v: str, T, default_value=None):
         v2 = v.upper().replace("-", "_")
         ev = f"DT_RUNNER_{v2}"
         if ev not in os.environ:
-            logger.debug(f"not found {ev}")
+            logger.debug(f"not found {ev}, using default {v=} = {default_value!r}")
             return default_value
         val = os.environ[ev]
+        logger.info(f"Using {v=} = {ev} = {val!r}")
         res = T(val)
         return res
 
@@ -181,7 +184,9 @@ Usage:
     parser.add_argument("--one", dest="one", action="store_true", default=False)
     parser.add_argument("--keep-registry", dest="do_not_mess_with_repo", action="store_true", default=False)
     parser.add_argument(
-        "--machine-id", help="Machine name", default=get_env_value_or_none("machine-id", str),
+        "--machine-id",
+        help="Machine name",
+        default=get_env_value_or_none("machine-id", str),
     )
     parser.add_argument("--name", help="Evaluator name", default=get_env_value_or_none("name", str))
     parser.add_argument(
@@ -206,7 +211,11 @@ Usage:
     )
     parser.add_argument("--submission", default=None, help="evaluate this particular submission")
     parser.add_argument(
-        "--reset", dest="reset", action="store_true", default=False, help="Reset submission",
+        "--reset",
+        dest="reset",
+        action="store_true",
+        default=False,
+        help="Reset submission",
     )
     parser.add_argument(
         "--features", help="Features to declare", default=get_env_value_or_none("features", str, "{}")
@@ -233,7 +242,7 @@ Usage:
         except Exception:
             msg = "Cannot read credentials passed in env/cmd line"
             raise ZValueError(msg, c=c)
-        logger.info("Read credenitals", environment=list(creds), direct=list(credentials))
+        # logger.info("Read credentials", environment=list(creds), direct=list(credentials))
         credentials.update(creds)
 
     check_docker_environment()
@@ -391,6 +400,12 @@ class NothingLeft(ZException):
     pass
 
 
+def is_gpu_present():
+    res = os.path.exists("/proc/driver/nvidia/version")
+    logger.info(f"GPU present: {res}")
+    return res
+
+
 def get_features(more_features, use_ipfs: bool) -> EvaluatorFeaturesDict:
     import psutil
 
@@ -433,7 +448,7 @@ def get_features(more_features, use_ipfs: bool) -> EvaluatorFeaturesDict:
             logger.info("OK - IPFS still working well")
         features["ipfs"] = 1
 
-    features["gpu"] = os.path.exists("/proc/driver/nvidia/version")
+    features["gpu"] = is_gpu_present()
 
     for k, v in more_features.items():
         if k in features:
@@ -457,6 +472,7 @@ def upload_process(
     dirname: str,
     job_id: JobID,
     machine_id: str,
+    evaluator_name: str,
     process_id: str,
     evaluator_version: str,
     impersonate: bool,
@@ -510,6 +526,9 @@ def upload_process(
 
         except:
             logger.warning(traceback.format_exc())
+        #
+        # if not _uploaded:
+        #     continue
 
         # noinspection PyBroadException
         try:
@@ -528,7 +547,7 @@ def upload_process(
                 features={},
                 # features=features,
                 query_string=f"phase=upload_process&job_id={job_id}&version="
-                f"{evaluator_version}&machine_id={machine_id}",
+                f"{evaluator_version}&machine_id={machine_id}&evaluator_name={evaluator_name}",
             )
         except:
             logger.warning(traceback.format_exc())
@@ -536,7 +555,7 @@ def upload_process(
             if res_["abort"]:
                 break
 
-        time.sleep(random.uniform(10, 20))
+        time.sleep(random.uniform(15, 20))
 
     logger.info("upload_process terminated gracefully")
 
@@ -570,7 +589,7 @@ def go_(
 
     try:
         shell_config = read_shell_config()
-    except (ConfigNotPresent) as e:
+    except ConfigNotPresent as e:
         msg = f"Cannot find shell config: {e}"
         logger.warning(msg)
         shell_config = get_shell_config_default()
@@ -643,7 +662,17 @@ def go_(
     wd = wd0 + "-a-wd"
     fd = wd0 + "-a-fifos"
 
-    params = (aws_config, token, wd, job_id, machine_id, process_id, evaluator_version, impersonate)
+    params = (
+        aws_config,
+        token,
+        wd,
+        job_id,
+        machine_id,
+        evaluator_name,
+        process_id,
+        evaluator_version,
+        impersonate,
+    )
     p = ctx.Process(target=upload_process, args=params, daemon=True)
     p.start()
 
@@ -674,24 +703,27 @@ def go_(
                 msg_ = f"The server told us to abort the job because: {why}"
                 raise KeyboardInterrupt(msg_)
 
-    cr, uploaded = get_cr(
-        res=res,
-        wd=wd,
-        fd=fd,
-        do_upload=do_upload,
-        evaluator_name=evaluator_name,
-        job_id=job_id,
-        delete=delete,
-        debug_volumes=debug_volumes,
-        do_pull=do_pull,
-        copy_to_machine_cache=copy_to_machine_cache,
-        allow_host_network=allow_host_network,
-        use_ipfs=use_ipfs,
-        cd=cd,
-        heartbeat=heartbeat,
-        quota_cpu=quota_cpu,
-        credentials=credentials,
-    )
+    try:
+        cr, uploaded = get_cr(
+            res=res,
+            wd=wd,
+            fd=fd,
+            do_upload=do_upload,
+            evaluator_name=evaluator_name,
+            job_id=job_id,
+            delete=delete,
+            debug_volumes=debug_volumes,
+            do_pull=do_pull,
+            copy_to_machine_cache=copy_to_machine_cache,
+            allow_host_network=allow_host_network,
+            use_ipfs=use_ipfs,
+            cd=cd,
+            heartbeat=heartbeat,
+            quota_cpu=quota_cpu,
+            credentials=credentials,
+        )
+    finally:
+        p.terminate()
 
     msg = "Reporting status %s for job %s submission %s.\n\n%s\n\n%s\n\n%s" % (
         cr.get_status(),
@@ -836,7 +868,6 @@ def get_cr(
                     timeout_sec=timeout_sec,
                     allow_host_network=allow_host_network,
                     use_ipfs=use_ipfs,
-                    # server_host=server_host,
                     require_scores=require_scores,
                     heartbeat=heartbeat,
                     quota_cpu=quota_cpu,
@@ -971,7 +1002,8 @@ def run_single(
     add_extra_environment[ENV_CHALLENGE_STEP_NAME] = challenge_step_name
     add_extra_environment[ENV_SUBMISSION_ID] = str(submission_id)
     add_extra_environment[ENV_SUBMITTER_NAME] = submitter_name
-
+    if is_gpu_present():
+        add_extra_environment["AIDO_REQUIRE_GPU"] = "1"
     add_extra_environment[ChallengesConstants.SUBMISSION_CONTAINER_TAG] = solution_container
 
     labels = {
@@ -1021,7 +1053,7 @@ def run_single(
         for service_name, s in config["services"].items():
             image = s["image"]
             if "dummy" in image:
-                logger.info(f'skipping image {image}')
+                logger.debug(f"skipping image {image}")
                 continue
             docker_pull_retry(client, image, ntimes=4, wait=5, credentials=credentials, quiet=False)
     if valid_config:
@@ -1165,7 +1197,10 @@ def run_one(
                             container.update(cpu_period=cpu_period, cpu_quota=cpu_quota)
                             msg = "Applying CPU quota"
                             logger.debug(
-                                msg, service_name=service_name, cpu_period=cpu_period, cpu_quota=cpu_quota,
+                                msg,
+                                service_name=service_name,
+                                cpu_period=cpu_period,
+                                cpu_quota=cpu_quota,
                             )
 
             logger.debug(f"Starting services", services=services)
@@ -1224,8 +1259,9 @@ def run_one(
                 running = []
                 running_details = {}
                 for service_name, container_id in service2id.items():
-                    if service_name in exited2:
-                        continue
+                    # no, because we have a delayed exit strategy below
+                    # if service_name in exited2:
+                    #     continue
                     container = client.containers.get(container_id)
 
                     stats = container.stats(stream=False)
@@ -1406,7 +1442,7 @@ def get_config(
     quiet: bool = False,
 ):
     """
-        server_host: reachable from other ips
+    server_host: reachable from other ips
     """
     UID = os.getuid()
     GID = os.getgid()
@@ -1445,7 +1481,7 @@ def get_config(
             br.tag = None
         service["image"] = get_complete_tag(br)
 
-        logger.info(f'translating {image} -> {service["image"]}')
+        logger.debug(f'translating {image} -> {service["image"]}')
         if quiet:
             if not is_solution_container(service_name):
                 service["logging"] = {"driver": "none"}
