@@ -28,7 +28,13 @@ def only_copy_to_cache(toupload: Dict[RPath, str]) -> List[ArtefactDict]:
         mime_type = guess_mime_type(realfile)
         storage = {}
         uploaded.append(
-            dict(size=size, mime_type=mime_type, rpath=rpath, sha256hex=sha256hex, storage=storage,)
+            dict(
+                size=size,
+                mime_type=mime_type,
+                rpath=rpath,
+                sha256hex=sha256hex,
+                storage=storage,
+            )
         )
     return uploaded
 
@@ -44,7 +50,7 @@ def compute_sha256hex(filename) -> str:
 
 
 def get_file_from_cache(fn, sha256hex):
-    """ raises KeyError """
+    """raises KeyError"""
 
     if disable_cache:
         logger.warning("Forcing cache disabled.")
